
<!-- ページネーション -->
<div class="pagination">
    <span class="step-links">
    {% if page_obj.has_previous %}
    <a style="text-decoration:none;" href="?page={{ page_obj.previous_page_number }}" class="text-violet-home">
      <i class="bi bi-arrow-left-circle-fill" style="font-size:140%; color:black;"></i>
    </a>
    {% endif %}
    <span class="current">
        <strong>
	  {{ page_obj.number }} <i class="bi bi-three-dots"></i> {{ page_obj.paginator.num_pages }}
	</strong>
    </span>
    {% if page_obj.has_next %}
        <a style="text-decoration:none;" href="?page={{ page_obj.next_page_number }}" class="text-violet-home">
	  <i class="bi bi-arrow-right-circle-fill" style="font-size:140%; color:black;"></i>
	</a>
    {% endif %}
    </span>
</div>

