# Generated by Django 2.2.5 on 2024-03-20 08:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('blogs', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Popular',
        ),
    ]
