/*-- detail.html --*/

/* メインバー */
.blogs-mainbar figure { /* 大見出し枠のデザイン */
  padding-top: 5%;
  padding-bottom: 5%;
  padding-left: 3%;
  padding-right: 3%;
  margin-bottom: 3%;
}

.blogs-mainbar figure .display-6 { /* 大見出しタイトルのデザイン */
  line-height: 150%;
  font-weight: bold;
}

.blogs-mainbar figure button { /* 大見出しのボタンデザイン */
  font-size: 60%;
}

.blogs-mainbar .navbar { /* ナビバーボトムのデザイン */
  background-color: transparent; /* バックカラー透明 */
}

.blogs-mainbar .navbar i { /* ナビバーボトムの編集用アイコンのデザイン */
  font-size: 150%;
  color: gray;
}

.blogs-mainbar .navbar button { /* 大見出しのボタンデザイン */
  font-size: 60%;
}

/* メインバー終 */

/* サイドバー */
.blogs-sidebar img { /* サムネイルのデザイン */
  margin-top: 5%;
  margin-bottom: 5%;
}

.blogs-sidebar .stick { /* ナビタブを追従表示 */
  position: -webkit-sticky;
  position: sticky;
  top: 3%;
}

.blogs-sidebar .nav-tabs { /* ナビタブを追従表示 */
  margin-top: 5%;
}

/* サイド目次のスクロール */
.blogs-sidebar .toc {
  height: 500px;
  overflow-y: scroll;
  margin-top: 5%;
  /*margin-bottom: 50px;*/
}

.blogs-sidebar .toc a { /* 目次リンクのデザイン */
  text-decoration:none;
  color: black;
}

.blogs-sidebar .toc li { /* 目次リストのデザイン */
  list-style: none;
  /* line-height: 200%; */
  margin-top: 2%;
}

.blogs-sidebar #new-articl {
  margin-top: 5%;
  margin-left: 3%;
  margin-right: 3%;
}

.blogs-sidebar #new-articl a {
  text-decoration:none;
  color: black;
}

.blogs-sidebar #new-articl p {
  margin-top: 10%;
}

/* サイドバー終 */

/*-- detail.html終 --*/

/* レイアウトが崩れている時の確認用 */
/** {
    outline: 2px red solid;
}*/
