# Generated by Django 2.2.28 on 2025-11-09 01:29

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('blogs', '0007_category_color'),
    ]

    operations = [
        migrations.CreateModel(
            name='Advertisement',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('advertiser_name', models.CharField(max_length=200, verbose_name='広告主')),
                ('image', models.ImageField(blank=True, upload_to='', verbose_name='広告画像')),
                ('start_date', models.DateTimeField(verbose_name='開始日時')),
                ('end_date', models.DateTimeField(verbose_name='終了日時')),
            ],
        ),
        migrations.CreateModel(
            name='Anchorlink',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('anchor', models.CharField(max_length=200, verbose_name='アンカー')),
                ('url', models.URLField(verbose_name='URL')),
                ('advertisement', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='blogs.Advertisement')),
            ],
        ),
    ]
