# Generated by Django 2.2.28 on 2025-11-09 02:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('blogs', '0008_advertisement_anchorlink'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='advertisement',
            options={'verbose_name': '広告主リスト', 'verbose_name_plural': '広告主リスト'},
        ),
        migrations.AddField(
            model_name='advertisement',
            name='image_color',
            field=models.CharField(default='#ecf0f1', max_length=7, verbose_name='イメージカラー'),
        ),
    ]
